package model;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.Statement;
import java.util.ArrayList;

public class ContatoDAO {
    public boolean inserir(Contato c) {
        try {
            String sql = "INSERT INTO contato (nome, email, telefone, cidadeId) "
                    + "VALUES (?,?,?,?)";
            Connection con = Conexao.conectar();
            PreparedStatement ps = con.prepareStatement(sql);
            ps.setString(1, c.getNome());
            ps.setString(2, c.getEmail());
            ps.setString(3, c.getTelefone());
            ps.setInt(4, c.getCidade().getId());
            ps.execute();
            ps.close();
            con.close();
            return true;
        } catch (Exception e) {
            System.out.println("ContatoDAO::inserir");
            System.out.println(e.getMessage());
            return false;
        }
    }
    
    public boolean alterar(Contato c) {
        try {
            String sql = "UPDATE contato SET nome=?, email=?, telefone=?, cidadeId=? "
                    + "WHERE id=?";
            Connection con = Conexao.conectar();
            PreparedStatement ps = con.prepareStatement(sql);
            ps.setString(1, c.getNome());
            ps.setString(2, c.getEmail());
            ps.setString(3, c.getTelefone());
            ps.setInt(4, c.getCidade().getId());
            ps.setInt(5, c.getId());
            ps.execute();
            ps.close();
            con.close();
            return true;
        } catch (Exception e) {
            System.out.println("ContatoDAO::alterar");
            System.out.println(e.getMessage());
            return false;
        }
    }
    
    public boolean excluir(int id) {
        try {
            String sql = "DELETE FROM contato WHERE id=?";
            Connection con = Conexao.conectar();
            PreparedStatement ps = con.prepareStatement(sql);
            ps.setInt(1, id);
            ps.execute();
            ps.close();
            con.close();
            return true;
        } catch (Exception e) {
            System.out.println("ContatoDAO::excluir");
            System.out.println(e.getMessage());
            return false;
        }
    }
    
    public Contato recuperarPorId(int id) {
        try {
            String sql = "SELECT id, nome, email, telefone, cidadeId "
                    + "FROM contato WHERE id=?";
            Connection con = Conexao.conectar();
            PreparedStatement ps = con.prepareStatement(sql);
            ps.setInt(1, id);
            ResultSet rs = ps.executeQuery();
            Contato contato = null;
            if ( rs.next() ) {
                contato = new Contato();
                contato.setId(rs.getInt("id"));
                contato.setNome(rs.getString("nome"));
                contato.setEmail(rs.getString("email"));
                contato.setTelefone(rs.getString("telefone"));
                
                CidadeDAO daoCidade = new CidadeDAO();
                Cidade cidade = daoCidade.recuperarPorId( rs.getInt("cidadeId") );
                contato.setCidade(cidade);
            }
            ps.close();
            con.close();
            return contato;
        } catch (Exception e) {
            System.out.println("ContatoDAO::recuperarPorId");
            System.out.println(e.getMessage());
            return null;
        }
    }
    
    public ArrayList<Contato> getLista() {
        ArrayList<Contato> lista = new ArrayList<Contato>();
        try {
            String sql = "SELECT id, nome, email, telefone, cidadeId FROM contato";
            Connection con = Conexao.conectar();
            Statement st = con.createStatement();
            ResultSet rs = st.executeQuery(sql);
            
            CidadeDAO daoCidade = new CidadeDAO();
            while ( rs.next() ) {
                Contato contato = new Contato();
                contato.setId(rs.getInt("id"));
                contato.setNome(rs.getString("nome"));
                contato.setEmail(rs.getString("email"));
                contato.setTelefone(rs.getString("telefone"));
                
                Cidade cidade = daoCidade.recuperarPorId( rs.getInt("cidadeId") );
                contato.setCidade(cidade);
                
                lista.add(contato);
            }
            System.out.println("ContatoDAO::getLista");
            rs.close();
            con.close();
        } catch (Exception e) {
            System.out.println("ContatoDAO::getLista");
            System.out.println(e.getMessage());
        }
        return lista;
    }
}
