package model;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.ArrayList;
import java.util.List;

public class PerfilDAO {
    public Perfil recuperarPorId(int id) {
        try {
            String sql = "SELECT p.id, p.nome Perfil, "
                            + "m.Nome Menu, m.Pagina, MenuId, m.Exibir "
                        + "FROM Perfil p "
                        + "INNER JOIN PerfilMenu pm ON p.Id = pm.PerfilId "
                        + "INNER JOIN Menu m ON pm.MenuId = m.Id "
                        + "WHERE p.id=?";
            Connection con = Conexao.conectar();
            PreparedStatement ps = con.prepareStatement(sql);
            ps.setInt(1, id);
            ResultSet rs = ps.executeQuery();
            Perfil perfil = null;
            if ( rs.next() ) {
                perfil = new Perfil();
                perfil.setId(rs.getInt("Id"));
                perfil.setNome(rs.getString("Perfil"));
                List<Menu> listaMenu = new ArrayList<Menu>();
                do {
                    Menu menu = new Menu();
                    menu.setId(rs.getInt("MenuId"));
                    menu.setNome(rs.getString("Menu"));
                    menu.setPagina(rs.getString("Pagina"));
                    menu.setExibir(rs.getBoolean("Exibir"));
                    listaMenu.add(menu);
                } while( rs.next() );
                
                perfil.setMenus(listaMenu);
            }
            ps.close();
            con.close();
            return perfil;
        } catch (Exception e) {
            System.out.println("PerfilDAO::recuperarPorId");
            System.out.println(e.getMessage());
            return null;
        }
    }
    
    public boolean inserir(Perfil p) {
        try {
            String sql = "INSERT INTO perfil (nome, excluido) VALUES (?,0)";
            Connection con = Conexao.conectar();
            // o comando PreparedStatement.RETURN_GENERATED_KEYS depois do SQL serve para informar que deve retornar o ID
            // do último registro inserido
            PreparedStatement ps = con.prepareStatement(sql, PreparedStatement.RETURN_GENERATED_KEYS);
            ps.setString(1, p.getNome());
            ps.execute();
            
            // recuperar o ID criado pelo banco de dados para o perfil inserido
            ResultSet rs = ps.getGeneratedKeys();
            if ( rs.next() ) {
                p.setId( rs.getInt(1) );
            }
            rs.close();
            ps.close();
            con.close();
            
            PerfilMenuDAO pmDao = new PerfilMenuDAO();
            return pmDao.gravar(p);
        } catch (Exception e) {
            System.out.println("PerfilDAO::inserir");
            System.out.println(e.getMessage());
            return false;
        }
    }
    
    public boolean alterar(Perfil p) {
        try {
            Connection con = Conexao.conectar();
            String sql = "UPDATE perfil SET nome=? WHERE id=?";
            PreparedStatement ps = con.prepareStatement(sql);
            ps.setString(1, p.getNome());
            ps.setInt(5, p.getId());
            ps.execute();
            ps.close();
            con.close();
            
            PerfilMenuDAO pmDao = new PerfilMenuDAO();
            return pmDao.gravar(p);
        } catch (Exception e) {
            System.out.println("PerfilDAO::alterar");
            System.out.println(e.getMessage());
            return false;
        }
    }
    public List<Perfil> getLista() {
        List<Perfil> lista = new ArrayList<Perfil>();
        try {
            String sql = "SELECT * FROM perfil WHERE Excluido = 0";
            Connection con = Conexao.conectar();
            Statement st = con.createStatement();
            ResultSet rs = st.executeQuery(sql);
            
            while ( rs.next() ) {
                Perfil perfil = new Perfil();
                perfil.setId(rs.getInt("id"));
                perfil.setNome(rs.getString("nome"));
                lista.add(perfil);
            }
            System.out.println("PerfilDAO::getLista");
            rs.close();
            con.close();
        } catch (Exception e) {
            System.out.println("PerfilDAO::getLista");
            System.out.println(e.getMessage());
        }
        return lista;
    }
    
    public boolean excluir(int id) {
        try {
            String sql = "UPDATE perfil SET Excluido = 1 WHERE id=?";
            Connection con = Conexao.conectar();
            PreparedStatement ps = con.prepareStatement(sql);
            ps.setInt(1, id);
            ps.execute();
            ps.close();
            con.close();
            return true;
        } catch (Exception e) {
            System.out.println("PerfilDAO::excluir");
            System.out.println(e.getMessage());
            return false;
        }
    }    
}
